module.exports = {
  parser: 'hermes-eslint',
  extends: [
    require.resolve('./packages/eslint-config-fbjs'),
  ],
};
